==> bootstrap-7.0.2.tgz: package/tsDist/components/dashboard/shared/SessionList/styles.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from 'styled-components';
import ContentLoader from 'react-content-loader';
import { ChevronRight } from 'components/icons';
import { Box, TableBody, TableHeaderCell, TableCell, TableRow, Table, } from 'components/elements';
import { WidgetButton } from '../../Widget';
export var SessionListContainer = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  height: 25em;\n"], ["\n  height: 25em;\n"])));
export var WidgetHeader = styled.div({
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: '0.5em 1em',
});
export var WidgetHead = styled.h3({
    margin: 0,
    fontSize: '24px',
    fontWeight: 'bold',
}, function (_a) {
    var theme = _a.theme;
    return ({
        color: theme.colors.primaryText.default,
    });
});
export var GoButton = styled(WidgetButton)(function (_a) {
    var theme = _a.theme;
    return ({
        color: '#fff',
        backgroundColor: theme.colors.primary.dark,
        transition: '0.2s all',
        '&:hover, &:focus, &:active, &:active:hover': {
            color: 'white',
            backgroundColor: theme.colors.primary.hover,
        },
    });
});
export var TableWrapper = styled.div(function (_a) {
    var _b;
    var theme = _a.theme;
    return (_b = {
            maxHeight: 340,
            overflow: 'auto',
            fontSize: '0.85em',
            color: theme.colors.primaryText.default
        },
        _b[Table] = {
            marginBottom: 0,
        },
        _b);
});
export var ErrorWrapper = styled(TableWrapper)({
    display: 'flex',
    height: 340,
    justifyContent: 'center',
    alignItems: 'center',
});
export var THeaderCellSmall = styled(TableHeaderCell)({
    fontWeight: 'normal',
    padding: '0.5em 1em',
});
export var TBodyHighlighted = styled(TableBody)(function (_a) {
    var isOpened = _a.isOpened;
    return ({
        backgroundColor: isOpened ? '#ececec' : 'transparent',
        '&:last-child td': {
            borderBottom: 'none',
        },
        '&:hover': {
            backgroundColor: isOpened ? '#ececec' : '#f6f8fb',
        },
    });
});
export var TCellSmall = styled(TableCell)(function (_a) {
    var _b = _a.width, width = _b === void 0 ? '50%' : _b;
    return ({
        padding: '0.5em 1em',
        borderBottom: '1px solid #e0e0e0',
        width: width,
    });
});
export var NewStatus = styled.span(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  color: ", ";\n  font-weight: 700;\n"], ["\n  color: ", ";\n  font-weight: 700;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primary.default;
});
export var ToggleArrow = styled(ChevronRight)(function (_a) {
    var isOpened = _a.isOpened;
    return ({
        width: 14,
        height: 14,
        backgroundColor: '#fff',
        border: '1px solid #E3E3E5',
        borderRadius: 4,
        marginRight: '1em',
        transform: "rotate(" + (isOpened ? '90deg' : '0deg') + ")",
        transition: '0.2s transform',
    });
});
export var SessionNameWrapper = styled.div({
    display: 'flex',
    alignItems: 'center',
    height: '2.9em',
});
export var ClickableTableRow = styled(TableRow)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  cursor: pointer;\n"], ["\n  cursor: pointer;\n"])));
export var ProgressBarContainer = styled.div({
    display: 'flex',
    width: '50%',
    marginTop: '2px',
});
export var ProgressText = styled(Box)(function (_a) {
    var theme = _a.theme;
    return ({
        color: theme.colors.secondaryText.dark,
        lineHeight: '1em',
    });
});
export var Bar = styled.div({
    height: 0,
    borderWidth: '2px',
    borderStyle: 'solid',
    margin: '0 1px',
}, function (_a) {
    var theme = _a.theme, progress = _a.progress, _b = _a.active, active = _b === void 0 ? false : _b;
    var color = active
        ? theme.colors.primary.default
        : theme.colors.secondaryText.light;
    return {
        borderColor: color,
        backgroundColor: color,
        flexBasis: progress + "%",
    };
});
export var ButtonsWrapper = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  display: flex;\n  justify-content: flex-end;\n"], ["\n  display: flex;\n  justify-content: flex-end;\n"])));
export var DetailsContainer = styled(Box)({
    padding: '5px 20px 10px',
    alignItems: 'center',
    'div b, div span': {
        marginRight: '5px',
    },
});
export var DetailsItemButtonWrapper = styled.div({
    width: '100%',
    marginTop: '1em',
});
export var DetailItemWrapper = styled.div(function (_a) {
    var theme = _a.theme;
    return ({
        marginRight: '1.5em',
        span: {
            color: theme.colors.secondaryText.dark,
        },
    });
});
export var StyledContentLoader = styled(ContentLoader)(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 48px;\n"], ["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 48px;\n"])));
export var NodeHrefLink = styled.a(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n  text-decoration: none;\n  color: ", ";\n  &:hover,\n  &:focus,\n  &:active {\n    color: ", ";\n    text-decoration: none;\n  }\n"], ["\n  text-decoration: none;\n  color: ", ";\n  &:hover,\n  &:focus,\n  &:active {\n    color: ", ";\n    text-decoration: none;\n  }\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primaryText.default;
}, function (_a) {
    var theme = _a.theme;
    return theme.colors.primaryText.light;
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6;

==> bootstrap-7.0.15.tgz: package/tsDist/components/dashboard/shared/SessionList/styles.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from 'styled-components';
import ContentLoader from 'react-content-loader';
import { ChevronRight } from 'components/icons';
import { Box, TableBody, TableHeaderCell, TableCell, TableRow, } from 'components/elements';
import { WidgetButton } from '../../Widget';
export var WidgetHeader = styled.div({
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: '0.5em 1em',
});
export var WidgetHead = styled.h3({
    margin: 0,
    fontSize: '24px',
    fontWeight: 'bold',
}, function (_a) {
    var theme = _a.theme;
    return ({
        color: theme.colors.primaryText.default,
    });
});
export var GoButton = styled(WidgetButton)(function (_a) {
    var theme = _a.theme;
    return ({
        color: '#fff',
        backgroundColor: theme.colors.primary.dark,
        transition: '0.2s all',
        '&:hover, &:focus, &:active, &:active:hover': {
            color: 'white',
            backgroundColor: theme.colors.primary.hover,
        },
    });
});
export var TableWrapper = styled.div(function (_a) {
    var theme = _a.theme;
    return ({
        maxHeight: 340,
        overflow: 'auto',
        fontSize: '0.85em',
        color: theme.colors.primaryText.default,
    });
});
export var ErrorWrapper = styled(TableWrapper)({
    display: 'flex',
    height: 340,
    justifyContent: 'center',
    alignItems: 'center',
});
export var THeaderCellSmall = styled(TableHeaderCell)({
    fontWeight: 'normal',
    padding: '0.5em 1em',
});
export var TBodyHighlighted = styled(TableBody)(function (_a) {
    var isOpened = _a.isOpened;
    return ({
        backgroundColor: isOpened ? '#ececec' : 'transparent',
        '&:last-child td': {
            borderBottom: 'none',
        },
        '&:hover': {
            backgroundColor: isOpened ? '#ececec' : '#f6f8fb',
        },
    });
});
export var TCellSmall = styled(TableCell)(function (_a) {
    var _b = _a.width, width = _b === void 0 ? '50%' : _b;
    return ({
        padding: '0.5em 1em',
        borderBottom: '1px solid #e0e0e0',
        width: width,
    });
});
export var NewStatus = styled.span(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  color: ", ";\n  font-weight: 700;\n"], ["\n  color: ", ";\n  font-weight: 700;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primary.default;
});
export var ToggleArrow = styled(ChevronRight)(function (_a) {
    var isOpened = _a.isOpened;
    return ({
        width: 14,
        height: 14,
        backgroundColor: '#fff',
        border: '1px solid #E3E3E5',
        borderRadius: 4,
        marginRight: '1em',
        transform: "rotate(" + (isOpened ? '90deg' : '0deg') + ")",
        transition: '0.2s transform',
    });
});
export var SessionNameWrapper = styled.div({
    display: 'flex',
    alignItems: 'center',
});
export var ClickableTableRow = styled(TableRow)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  cursor: pointer;\n"], ["\n  cursor: pointer;\n"])));
export var ProgressBarContainer = styled.div({
    display: 'flex',
});
export var ProgressText = styled(Box)(function (_a) {
    var theme = _a.theme;
    return ({
        color: theme.colors.secondaryText.dark,
        lineHeight: 'normal',
    });
});
export var Bar = styled.div({
    height: 4,
    margin: '0 1px',
}, function (_a) {
    var theme = _a.theme, progress = _a.progress, _b = _a.active, active = _b === void 0 ? false : _b;
    var color = active
        ? theme.colors.primary.default
        : theme.colors.secondaryText.light;
    return {
        backgroundColor: color,
        flexBasis: progress + "%",
    };
});
export var ButtonsWrapper = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  display: flex;\n  justify-content: flex-end;\n"], ["\n  display: flex;\n  justify-content: flex-end;\n"])));
export var DetailsContainer = styled(Box)({
    padding: '5px 20px 10px',
    alignItems: 'center',
    'div b, div span': {
        marginRight: '5px',
    },
});
export var DetailsItemButtonWrapper = styled.div({
    width: '100%',
    marginTop: '1em',
});
export var DetailItemWrapper = styled.div(function (_a) {
    var theme = _a.theme;
    return ({
        marginRight: '1.5em',
        span: {
            color: theme.colors.secondaryText.dark,
        },
    });
});
export var StyledContentLoader = styled(ContentLoader)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 48px;\n"], ["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 48px;\n"])));
export var NodeHrefLink = styled.a(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  text-decoration: none;\n  color: ", ";\n  &:hover,\n  &:focus,\n  &:active {\n    color: ", ";\n    text-decoration: none;\n  }\n"], ["\n  text-decoration: none;\n  color: ", ";\n  &:hover,\n  &:focus,\n  &:active {\n    color: ", ";\n    text-decoration: none;\n  }\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primaryText.default;
}, function (_a) {
    var theme = _a.theme;
    return theme.colors.primaryText.light;
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;
